# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x43ommon.proto\x12\x06\x43ommon\"(\n\x06result\x12\x0e\n\x06result\x18\x01 \x01(\x05\x12\x0e\n\x06reason\x18\x02 \x01(\t\"\x07\n\x05\x65mpty\"0\n\x07version\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x14\n\x0crelease_date\x18\x02 \x01(\t\"*\n\x08net_info\x12\x0f\n\x07ip_addr\x18\x01 \x01(\t\x12\r\n\x05iface\x18\x02 \x01(\t\"\x19\n\tfile_path\x12\x0c\n\x04path\x18\x01 \x01(\tb\x06proto3')



_RESULT = DESCRIPTOR.message_types_by_name['result']
_EMPTY = DESCRIPTOR.message_types_by_name['empty']
_VERSION = DESCRIPTOR.message_types_by_name['version']
_NET_INFO = DESCRIPTOR.message_types_by_name['net_info']
_FILE_PATH = DESCRIPTOR.message_types_by_name['file_path']
result = _reflection.GeneratedProtocolMessageType('result', (_message.Message,), {
  'DESCRIPTOR' : _RESULT,
  '__module__' : 'Common_pb2'
  # @@protoc_insertion_point(class_scope:Common.result)
  })
_sym_db.RegisterMessage(result)

empty = _reflection.GeneratedProtocolMessageType('empty', (_message.Message,), {
  'DESCRIPTOR' : _EMPTY,
  '__module__' : 'Common_pb2'
  # @@protoc_insertion_point(class_scope:Common.empty)
  })
_sym_db.RegisterMessage(empty)

version = _reflection.GeneratedProtocolMessageType('version', (_message.Message,), {
  'DESCRIPTOR' : _VERSION,
  '__module__' : 'Common_pb2'
  # @@protoc_insertion_point(class_scope:Common.version)
  })
_sym_db.RegisterMessage(version)

net_info = _reflection.GeneratedProtocolMessageType('net_info', (_message.Message,), {
  'DESCRIPTOR' : _NET_INFO,
  '__module__' : 'Common_pb2'
  # @@protoc_insertion_point(class_scope:Common.net_info)
  })
_sym_db.RegisterMessage(net_info)

file_path = _reflection.GeneratedProtocolMessageType('file_path', (_message.Message,), {
  'DESCRIPTOR' : _FILE_PATH,
  '__module__' : 'Common_pb2'
  # @@protoc_insertion_point(class_scope:Common.file_path)
  })
_sym_db.RegisterMessage(file_path)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESULT._serialized_start=24
  _RESULT._serialized_end=64
  _EMPTY._serialized_start=66
  _EMPTY._serialized_end=73
  _VERSION._serialized_start=75
  _VERSION._serialized_end=123
  _NET_INFO._serialized_start=125
  _NET_INFO._serialized_end=167
  _FILE_PATH._serialized_start=169
  _FILE_PATH._serialized_end=194
# @@protoc_insertion_point(module_scope)
